@@ -17,15 +17,19 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef KDED_CONFIG_H
 #define KDED_CONFIG_H
 
-
 #include <kscreen/config.h>
 
+#include <QOrientationReading>
+
 #include <memory>
 
-class Config
+class ControlConfig;
+
+class Config : public QObject
 {
+    Q_OBJECT
 public:
-    explicit Config(KScreen::ConfigPtr config);
+    explicit Config(KScreen::ConfigPtr config, QObject *parent = nullptr);
     ~Config() = default;
 
     QString id() const;
@@ -40,6 +44,9 @@ public:
         return m_data;
     }
 
+    void activateControlWatching();
+    bool autoRotationRequested() const;
+    void setDeviceOrientation(QOrientationReading::Orientation orientation);
     void log();
 
     void setValidityFlags(KScreen::Config::ValidityFlags flags) {
@@ -48,6 +55,9 @@ public:
 
     bool canBeApplied() const;
 
+Q_SIGNALS:
+    void controlChanged();
+
 private:
     friend class TestConfig;
 
@@ -59,6 +69,7 @@ private:
 
     KScreen::ConfigPtr m_data;
     KScreen::Config::ValidityFlags m_validityFlags;
+    ControlConfig *m_control;
 
     static QString s_configsDirName;
     static QString s_fixedConfigFileName;
